pub trait LinkedDataDeserializePredicateObjects<I: Interpretation = (), V: Vocabulary = ()>: Sized {
// Required method
fn deserialize_objects_in<'a, D>(
vocabulary: &V,
interpretation: &I,
dataset: &D,
graph: Option<&I::Resource>,
objects: impl IntoIterator<Item = &'a I::Resource>,
context: Context<'_, I>,
) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a,
D: PatternMatchingDataset<Resource = I::Resource>;
// Provided method
fn deserialize_objects<'a, D>(
vocabulary: &V,
interpretation: &I,
dataset: &D,
graph: Option<&I::Resource>,
objects: impl IntoIterator<Item = &'a I::Resource>,
) -> Result<Self, FromLinkedDataError>
where I::Resource: 'a,
D: PatternMatchingDataset<Resource = I::Resource> { ... }
}Required Methods
fn deserialize_objects_in<'a, D>( vocabulary: &V, interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
Provided Methods
fn deserialize_objects<'a, D>( vocabulary: &V, interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, ) -> Result<Self, FromLinkedDataError>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<I, V: Vocabulary, T: LinkedDataDeserializeSubject<I, V>> LinkedDataDeserializePredicateObjects<I, V> for Option<T>
impl<I, V: Vocabulary, T: LinkedDataDeserializeSubject<I, V>> LinkedDataDeserializePredicateObjects<I, V> for Option<T>
fn deserialize_objects_in<'a, D>( vocabulary: &V, interpretation: &I, dataset: &D, graph: Option<&I::Resource>, objects: impl IntoIterator<Item = &'a I::Resource>, context: Context<'_, I>, ) -> Result<Self, FromLinkedDataError>
Sourceimpl<I, V: Vocabulary, T: LinkedDataDeserializeSubject<I, V>> LinkedDataDeserializePredicateObjects<I, V> for Vec<T>
Deserialized by walking an rdf:List (a chain of blank nodes linked by
rdf:first/rdf:rest, terminated by rdf:nil), preserving element
order. A predicate with no value at all is treated as an empty list.
impl<I, V: Vocabulary, T: LinkedDataDeserializeSubject<I, V>> LinkedDataDeserializePredicateObjects<I, V> for Vec<T>
Deserialized by walking an rdf:List (a chain of blank nodes linked by
rdf:first/rdf:rest, terminated by rdf:nil), preserving element
order. A predicate with no value at all is treated as an empty list.